#!/usr/bin/env python
# Copyright 2006, CRIM, Revolution Linux Inc.
#
# $Id$
#
# Authors : Francis Giraldeau <francis.giraldeau@revolutionlinux.com>
# Modified by Patrice Gauvin <pgauvin@cslaval.qc.ca>
# This file is part of the MILLE-XTERM project.
#
#		http://www.revolutionlinux.com/mille-xterm/
#		http://www.mille.ca/
#
# This program is covered by the GNU General Public License.
# See the COPYING file in the top-level MILLE-XTERM directory.
#
# -------------------------------------------------------------------------

"""
Script to auto-configure the application server
"""

#import configparse import OptionParser
import cfgparse
import os
import sys
import glob
import shutil
import string

xtroot = "/opt/xtermroot"
gdm_config_file = "/etc/X11/gdm/gdm.conf"
desktop_file = "/etc/sysconfig/desktop"

def backup(file):
	if not os.path.isfile(file):
		return
	print " * Making backup of", file
	num = string.zfill(len(glob.glob(file + "*")),3)
	shutil.copy2(file, file + "." + str(num))

def defaultManager():
	"""configure GDM as default manager"""
	print "\nConfiguration the display manager to use GDM as default :"
	# backup the config file before anything
	backup(desktop_file)
	f = open(desktop_file,"w")
	f.write("DESKTOP-KDE\n")
	f.write("DISPLAYMANAGER=GDM\n")
	f.close()
	print " * Display manager configuration added in " + desktop_file
	
def configGDM():
	"""configuration of GDM options"""
	print "Configuration of GDM :"
	# backup the config file before anything
	backup(gdm_config_file)
	
	print " * Adding GDM configuration in " + gdm_config_file
	if not os.path.isfile(gdm_config_file):
		print " * Error : Can't configure GDM because", gdm_config_file + " is not found.\nConfiguration aborded !"
		sys.exit(1)
		return
	
	c = cfgparse.ConfigParser()
	f = c.add_file(gdm_config_file)
	f.set_option("Enable","true",keys="xdmcp")
	f.set_option("PingIntervalSeconds","10",keys="xdmcp")
	f.set_option("MaxSessions","100",keys="xdmcp")
	f.set_option("DisallowTCP","false",keys="security")
	f.set_option("RemoteGreeter","/usr/lib/gdmgreeter",keys="daemon")
	f.set_option("SystemMenu","true",keys="greeter")
	f.set_option("GraphicalTheme","millexterm",keys="greeter")
	f.set_option("DefaultWelcome","false",keys="greeter")
	f.set_option("Welcome","Application Server (%n)",keys="greeter")

	f.write(gdm_config_file)
	
	#os.system("/usr/sbin/gdm-safe-restart")


# configuration of pxe, tftpd and dhcp if enabled

def main():
	print "Starting configuration...\n"
	configGDM()
	defaultManager()
        print "Configuration complete !\n"
        print " ****************************************************************"
	print " * To use new settings, you must restart GDM.                   *"
	print " * You can use this command : nohup /etc/init.d/dm restart      *"
	print " * Warning : this command will terminate all running X sessions *"
	print " ****************************************************************\n"
	print "If you use the loadbalancer system (recommended) your can enable/disable the discovery of your application server to your"
	print "boots servers with lbagent. You can manage lbagent whith this command : service lbagent [start|stop|restart]\n"	
	
if __name__=="__main__":
	main()
